@@ -88,7 +88,7 @@ class Promotions extends CGExtensions
    ---------------------------------------------------------*/
   public function GetVersion()
   {
-    return '1.0.13';
+    return '1.0.16';
   }
 
 
@@ -194,7 +194,7 @@ class Promotions extends CGExtensions
    ---------------------------------------------------------*/
   public function MinimumCMSVersion()
   {
-    return "1.6.7";
+    return "1.9.4.3";
   }
 	
 	
@@ -262,7 +262,7 @@ legend.cglegend {
 }
 </style>
 EOT;
-    $obj =& $this->GetModuleInstance('JQueryTools');
+    $obj = $this->GetModuleInstance('JQueryTools');
     if( is_object($obj) )
       {
 $tmpl = <<<EOT
@@ -340,14 +340,14 @@ EOT;
     foreach( $promotion_ids as $promo_id )
       {
 	$match_type = '';
-	$promo =& promo_ops::load_promo_by_id($promo_id);
+	$promo = promo_ops::load_promo_by_id($promo_id);
 	if( !$promo ) continue;
 
 	// check all of the conditions in the promotion
 	$match = true;
 	for( $i = 0; $i < $promo->count_conditions(); $i++ )
 	  {
-	    $condition =& $promo->get_condition($i);
+	    $condition = $promo->get_condition($i);
 	    
 	    switch( $condition->get_cond_type() )
 	      {
@@ -471,13 +471,13 @@ EOT;
     $best_discount = '';
     foreach( $promotion_ids as $promo_id )
       {
-	$promo =& promo_ops::load_promo_by_id($promo_id);
+	$promo = promo_ops::load_promo_by_id($promo_id);
 	if( !$promo ) continue;
 
 	$match = true;
 	for( $i = 0; $i < $promo->count_conditions(); $i++ )
 	  {
-	    $condition =& $promo->get_condition($i);
+	    $condition = $promo->get_condition($i);
 	    
 	    switch( $condition->get_cond_type() )
 	      {
