@@ -46,9 +46,7 @@ class promo_ops
 
   private static function &_get_products_mod()
   {
-    global $gCms;
-    $products =& $gCms->modules['Products']['object'];
-    return $products;
+    return cms_utils::get_module('Products');
   }
 
   private static function &_get_product($product_id)
